EXPORTS
	??1CAknFepRepositoryWatcher@@UAE@XZ @ 1 NONAME ; CAknFepRepositoryWatcher::~CAknFepRepositoryWatcher(void)
	??1CAknFepTimer@@UAE@XZ @ 2 NONAME ; CAknFepTimer::~CAknFepTimer(void)
	?ChangedKey@CAknFepRepositoryWatcher@@QAEKXZ @ 3 NONAME ; unsigned long CAknFepRepositoryWatcher::ChangedKey(void)
	?HandleNotifyError@CAknFepRepositoryWatcher@@UAEXKHPAVCCenRepNotifyHandler@@@Z @ 4 NONAME ; void CAknFepRepositoryWatcher::HandleNotifyError(unsigned long, int, class CCenRepNotifyHandler *)
	?HandleNotifyGeneric@CAknFepRepositoryWatcher@@UAEXK@Z @ 5 NONAME ; void CAknFepRepositoryWatcher::HandleNotifyGeneric(unsigned long)
	?HandleNotifyInt@CAknFepRepositoryWatcher@@UAEXKH@Z @ 6 NONAME ; void CAknFepRepositoryWatcher::HandleNotifyInt(unsigned long, int)
	?NewL@CAknFepRepositoryWatcher@@SAPAV1@VTUid@@KW4TCenRepKeyType@CCenRepNotifyHandler@@VTCallBack@@PAVCRepository@@@Z @ 7 NONAME ; class CAknFepRepositoryWatcher * CAknFepRepositoryWatcher::NewL(class TUid, unsigned long, enum CCenRepNotifyHandler::TCenRepKeyType, class TCallBack, class CRepository *)
	?NewL@CAknFepRepositoryWatcher@@SAPAV1@VTUid@@VTCallBack@@PAVCRepository@@@Z @ 8 NONAME ; class CAknFepRepositoryWatcher * CAknFepRepositoryWatcher::NewL(class TUid, class TCallBack, class CRepository *)
	?NewL@CAknFepTimer@@SAPAV1@PAVMAknFepTimerHandler@@@Z @ 9 NONAME ; class CAknFepTimer * CAknFepTimer::NewL(class MAknFepTimerHandler *)
	?SetTimer@CAknFepTimer@@QAEXABVTTimeIntervalMicroSeconds32@@@Z @ 10 NONAME ; void CAknFepTimer::SetTimer(class TTimeIntervalMicroSeconds32 const &)
	?GetISOLanguageCode@AknPenInputUtils@@SAHW4TLanguage@@AAVTDes16@@@Z @ 11 NONAME ; int AknPenInputUtils::GetISOLanguageCode(enum TLanguage, class TDes16 &)
	?CombineTwoImagesL@AknPenImageUtils@@SAPAVCFbsBitmap@@PBV2@0W4TDisplayMode@@H@Z @ 12 NONAME ; class CFbsBitmap * AknPenImageUtils::CombineTwoImagesL(class CFbsBitmap const *, class CFbsBitmap const *, enum TDisplayMode, int)
	?StartAppL@AknPenInputUtils@@SAXABVTDesC16@@@Z @ 13 NONAME ; void AknPenInputUtils::StartAppL(class TDesC16 const &)
	?Draw3PiecesFrame@AknPenInputDrawUtils@@SAXPAVMAknsSkinInstance@@AAVCFbsBitGc@@ABVTRect@@22ABVTAknsItemID@@33@Z @ 14 NONAME ; void AknPenInputDrawUtils::Draw3PiecesFrame(class MAknsSkinInstance *, class CFbsBitGc &, class TRect const &, class TRect const &, class TRect const &, class TAknsItemID const &, class TAknsItemID const &, class TAknsItemID const &)
	?Draw3PiecesFrame@AknPenInputDrawUtils@@SAXPAVMAknsSkinInstance@@AAVCFbsBitGc@@ABVTRect@@2ABVTAknsItemID@@33@Z @ 15 NONAME ; void AknPenInputDrawUtils::Draw3PiecesFrame(class MAknsSkinInstance *, class CFbsBitGc &, class TRect const &, class TRect const &, class TAknsItemID const &, class TAknsItemID const &, class TAknsItemID const &)
	?CalculateGraphicRect@AknPenImageUtils@@SAXABVTRect@@AAV2@@Z @ 16 NONAME ; void AknPenImageUtils::CalculateGraphicRect(class TRect const &, class TRect &)
	?ConstructFromResourceL@CPenInputColorIcon@@UAEXH@Z @ 17 NONAME ; void CPenInputColorIcon::ConstructFromResourceL(int)
	?Draw3PiecesColorIcon@AknPenInputDrawUtils@@SAXPAVCPenInput3PiecesColorIcons@@AAVCFbsBitGc@@ABVTRect@@2@Z @ 18 NONAME ; void AknPenInputDrawUtils::Draw3PiecesColorIcon(class CPenInput3PiecesColorIcons *, class CFbsBitGc &, class TRect const &, class TRect const &)
	?DrawColorIcon@AknPenInputDrawUtils@@SAXPAVCPenInputColorIcon@@AAVCFbsBitGc@@ABVTRect@@@Z @ 19 NONAME ; void AknPenInputDrawUtils::DrawColorIcon(class CPenInputColorIcon *, class CFbsBitGc &, class TRect const &)
	?NewL@CPenInput3PiecesColorIcons@@SAPAV1@HHH@Z @ 20 NONAME ; class CPenInput3PiecesColorIcons * CPenInput3PiecesColorIcons::NewL(int, int, int)
	?NewL@CPenInputColorIcon@@SAPAV1@H@Z @ 21 NONAME ; class CPenInputColorIcon * CPenInputColorIcon::NewL(int)
	?NewLC@CPenInput3PiecesColorIcons@@SAPAV1@HHH@Z @ 22 NONAME ; class CPenInput3PiecesColorIcons * CPenInput3PiecesColorIcons::NewLC(int, int, int)
	?NewLC@CPenInputColorIcon@@SAPAV1@H@Z @ 23 NONAME ; class CPenInputColorIcon * CPenInputColorIcon::NewLC(int)
	?ResizeL@CPenInputColorIcon@@UAEXABVTSize@@@Z @ 24 NONAME ; void CPenInputColorIcon::ResizeL(class TSize const &)
	?ReConstructL@CPenInput3PiecesColorIcons@@QAEXXZ @ 25 NONAME ; void CPenInput3PiecesColorIcons::ReConstructL(void)
	?NewL@CPeninputSyncBitmapRotator@@SAPAV1@XZ @ 26 NONAME ; class CPeninputSyncBitmapRotator * CPeninputSyncBitmapRotator::NewL(void)
	?Rotate@CPeninputSyncBitmapRotator@@QAEHAAVCFbsBitmap@@0W4TRotationAngle@CBitmapRotator@@@Z @ 27 NONAME ; int CPeninputSyncBitmapRotator::Rotate(class CFbsBitmap &, class CFbsBitmap &, enum CBitmapRotator::TRotationAngle)
	?Rotate@CPeninputSyncBitmapRotator@@QAEHAAVCFbsBitmap@@W4TRotationAngle@CBitmapRotator@@@Z @ 28 NONAME ; int CPeninputSyncBitmapRotator::Rotate(class CFbsBitmap &, enum CBitmapRotator::TRotationAngle)
	?CalculateLongBtnGraphicRect@AknPenImageUtils@@SAXABVTRect@@AAV2@@Z @ 29 NONAME ; void AknPenImageUtils::CalculateLongBtnGraphicRect(class TRect const &, class TRect &)
	?CheckColorInColorTable@AknPenInputTrailColorUtils@@SAHH@Z @ 30 NONAME ; int AknPenInputTrailColorUtils::CheckColorInColorTable(int)
	?ColorAt@AknPenInputTrailColorUtils@@SA?AVTRgb@@H@Z @ 31 NONAME ; class TRgb AknPenInputTrailColorUtils::ColorAt(int)
	?ColorCount@AknPenInputTrailColorUtils@@SAHXZ @ 32 NONAME ; int AknPenInputTrailColorUtils::ColorCount(void)
	?GetTrailColorByTheme@AknPenInputTrailColorUtils@@SAHXZ @ 33 NONAME ; int AknPenInputTrailColorUtils::GetTrailColorByTheme(void)

